@@ -1,8 +1,9 @@
-# The visualizer class is used to show 3d point clouds or bounding boxes in the browser.
+"""The visualizer class is used to show 3d point clouds or bounding boxes in the browser."""
 
 from .points import Points
 from .cuboid import Cuboid
 from .lines import Lines
+from .mesh import Mesh
 from .camera import Camera
 import os
 import sys
@@ -30,7 +31,7 @@ class Visualizer:
     ):
         """Add points to the visualizer.
 
-        :param name: The name of the points displayed in the visualizer.
+        :param name: The name of the points displayed in the visualizer. Use ';' in the name to create sub-layers.
         :param positions: The point positions.
         :param normals: The point normals.
         :param colors: The point colors.
@@ -92,11 +93,26 @@ class Visualizer:
         """
         self.elements[name] = Cuboid(position, size, orientation)
 
+    def add_mesh(self, name, path, translation=[0, 0, 0], rotation=[0, 0, 0], scale=[1, 1, 1], color=[255, 255, 255], visible=True):
+        """Adds a polygon mesh to the scene, as specified in the path, it has to be an .obj file.
+
+        :param name: The name of the mesh displayed in the layers.
+        :param path: The path to the .obj polygon mesh file.
+        :param translation: The 3D tranlsation of the object.
+        :param rotation: The 3D rotation (Euler angles in rad) of the object.
+        :param scale: The 3D scaling of the original object.
+        :param color: The uniform color of the object.
+        :param visible: Whether the object is visible or not.
+        """
+        mesh = Mesh(path, translation=translation, rotation=rotation, scale=scale, color=color, visible=visible)
+        self.elements[name] = mesh
+
     def save(self, path, port=6008, verbose=True):
         """Creates the visualization and displays the link to it.
 
         :param path: The path to save the visualization files.
         :param port: The port to show the visualization.
+        :param verbose: Whether to print the web-server message or not.
         """
 
         # Delete destination directory if it exists already
